==> banshee-1-0.98.3.tar.bz2: banshee-1-0.98.3/src/Extensions/Banshee.Podcasting/Banshee.Podcasting.Gui/PodcastManager/Dialog/SyncPreferenceComboBox.cs <==
/***************************************************************************
 *  SyncPreferenceComboBox.cs
 *
 *  Copyright (C) 2007 Michael C. Urbanski
 *  Written by Mike Urbanski <michael.c.urbanski@gmail.com>
 ****************************************************************************/

/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW:
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),  
 *  to deal in the Software without restriction, including without limitation  
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,  
 *  and/or sell copies of the Software, and to permit persons to whom the  
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */
 
using Gtk;
using System;
using Mono.Unix;

using Banshee.Podcasting.Data;

namespace Banshee.Podcasting.Gui
{
    public class SyncPreferenceComboBox : Gtk.ComboBox
    {
        private static readonly string [] combo_text_entries = {
            Catalog.GetString ("Download all episodes"),
            Catalog.GetString ("Download the most recent episode"),
            Catalog.GetString ("Let me decide which episodes to download")
        };

        public SyncPreference ActiveSyncPreference 
        {
            get { return (SyncPreference) Active; }
        }

        public SyncPreferenceComboBox (SyncPreference syncPref) : base (combo_text_entries)
        {
            if ((int) syncPref >= (int) SyncPreference.All &&
                (int) syncPref <= (int) SyncPreference.None) {
                Active = (int) syncPref;
            } else {
                Active = (int) SyncPreference.One;
            }
        }

        public SyncPreferenceComboBox (): this (SyncPreference.One) {} 
    }
}

==> banshee-1-1.4.0.1.tar.bz2: banshee-1-1.4.0.1/src/Extensions/Banshee.Podcasting/Banshee.Podcasting.Gui/PodcastManager/Dialog/SyncPreferenceComboBox.cs <==
/***************************************************************************
 *  SyncPreferenceComboBox.cs
 *
 *  Copyright (C) 2007 Michael C. Urbanski
 *  Written by Mike Urbanski <michael.c.urbanski@gmail.com>
 ****************************************************************************/

/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW:
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),  
 *  to deal in the Software without restriction, including without limitation  
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,  
 *  and/or sell copies of the Software, and to permit persons to whom the  
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */
 
using Gtk;
using System;
using Mono.Unix;

using Migo.Syndication;
using Banshee.Podcasting.Data;

namespace Banshee.Podcasting.Gui
{
    public class SyncPreferenceComboBox : Gtk.ComboBox
    {
        private static readonly string [] combo_text_entries = {
            Catalog.GetString ("Download all episodes"),
            Catalog.GetString ("Download the most recent episode"),
            Catalog.GetString ("Let me decide which episodes to download")
        };

        public FeedAutoDownload ActiveSyncPreference 
        {
            get { return (FeedAutoDownload) Active; }
        }

        public SyncPreferenceComboBox (FeedAutoDownload syncPref) : base (combo_text_entries)
        {
            if ((int) syncPref >= (int) FeedAutoDownload.All &&
                (int) syncPref <= (int) FeedAutoDownload.None) {
                Active = (int) syncPref;
            } else {
                Active = (int) FeedAutoDownload.One;
            }
        }

        public SyncPreferenceComboBox (): this (FeedAutoDownload.One)
        {
        }
    }
}
